build method
Builds the pheasant application and renders it into the dom.
Specify selector to choose to render to a specific component like one with an id of "out" ("#out"). Defaults to "#output".
Implementation
void build([String selector = '#output']) {
createApp(app, appState: state, selector: selector);
}